/**
 * ClusterToc - parse a .clustertoc file
 * @author Peter Tribble
 * @version 1.0
 *
 */

package uk.co.petertribble.solview;

import uk.co.petertribble.jumble.*;
import java.io.File;
import java.util.*;

public class ClusterToc {

  private Hashtable Clusters;
  private Hashtable MetaClusters;

  public ClusterToc(File f) {
    Clusters = new Hashtable();
    MetaClusters = new Hashtable();
    String[] lines = JumbleUtils.stringToStringArray(JumbleFile.getStringContents(f),"\n");
    String thiscluster = "";
    PackageCluster thispkgcluster = null;
    for (int i = 0; i < lines.length; i++ ) {
      String[] ds = lines[i].split("=",2);
      if (ds[0].equals("CLUSTER")) {
	thiscluster = ds[1];
	thispkgcluster = new PackageCluster(thiscluster);
	Clusters.put(thiscluster, thispkgcluster);
      } else if (ds[0].equals("NAME")) {
	thispkgcluster.setName(ds[1]);
      } else if (ds[0].equals("SUNW_CSRMEMBER")) {
	thispkgcluster.addPackage(ds[1]);
      } else if (ds[0].equals("METACLUSTER")) {
	thiscluster = ds[1];
	thispkgcluster = new PackageCluster(thiscluster, true);
	MetaClusters.put(thiscluster, thispkgcluster);
      }
    }
  }

  public Hashtable getMetaClusters() {
    return MetaClusters;
  }

  public Hashtable getClusters() {
    return Clusters;
  }

  public PackageCluster getCluster(String s) {
    return (PackageCluster) Clusters.get(s);
  }

  public PackageCluster getMetaCluster(String s) {
    return (PackageCluster) MetaClusters.get(s);
  }

  public Hashtable getContainingClusters(String p) {
    Hashtable h = new Hashtable();
    for (Enumeration e = Clusters.keys(); e.hasMoreElements() ; ) {
      String cname = (String) e.nextElement();
      PackageCluster pclust = getCluster(cname);
      if (pclust.containsPackage(p)) {
	h.put(cname, pclust);
      }
    }
    return h;
  }
}
