/**
 * ClusterTree - A JTree representing Solaris packagesparse a .clustertoc file
 * @author Peter Tribble
 * @version 1.0
 *
 */

package uk.co.petertribble.solview;

import javax.swing.tree.*;
import java.util.*;

public class ClusterTree {

  private Hashtable Clusters;
  private Hashtable MetaClusters;

  /**
   * Create a tree from a clustertoc file and add it to the parent node
   *
   * @param topmenu  A tree node to attach the tree to
   * @param ctoc     A parsed cluster table of contents
   */
  public ClusterTree(DefaultMutableTreeNode topmenu, ClusterToc ctoc) {
    Clusters = ctoc.getClusters();
    MetaClusters = ctoc.getMetaClusters();
    //outer loop over metaclusters
    Enumeration em = MetaClusters.keys();
    while (em.hasMoreElements()) {
      String s = (String) em.nextElement();
      DefaultMutableTreeNode mitem = new DefaultMutableTreeNode(s);
      topmenu.add(mitem);
      PackageCluster pc = (PackageCluster) MetaClusters.get(s);
      Enumeration ec = pc.getPackages().elements();
      while (ec.hasMoreElements()) {
	mitem.add(addNode((String) ec.nextElement()));
      }
    }
  }

  /**
   * Create a tree from a clustertoc file and add it to the parent node
   *
   * @param topmenu  A tree node to attach the tree to
   * @param ctoc     A parsed cluster table of contents
   * @param cluster  The top-level metacluster to show
   */
  public ClusterTree(DefaultMutableTreeNode topmenu, ClusterToc ctoc, String cluster) {
    Clusters = ctoc.getClusters();
    MetaClusters = ctoc.getMetaClusters();
    //outer loop over metaclusters
    Enumeration em = MetaClusters.keys();
    while (em.hasMoreElements()) {
      String s = (String) em.nextElement();
      // only show this cluster
      if (s.equals(cluster)) {
	PackageCluster pc = (PackageCluster) MetaClusters.get(s);
	Enumeration ec = pc.getPackages().elements();
	while (ec.hasMoreElements()) {
	  topmenu.add(addNode((String) ec.nextElement()));
	}
      }
    }
  }

  //create the tree for a cluster
  private DefaultMutableTreeNode addNode(String s) {
    DefaultMutableTreeNode mitem = new DefaultMutableTreeNode(s);
    PackageCluster pc = (PackageCluster) Clusters.get(s);
    if (pc != null) {
      Enumeration ep = pc.getPackages().elements();
      while (ep.hasMoreElements()) {
	mitem.add(new DefaultMutableTreeNode((String) ep.nextElement()));
      }
    }
    return mitem;
  }
}
