/**
 * ContentsFileDetail - describes a line in the contents file
 * @author Peter Tribble
 * @version 1.0
 *
 */

package uk.co.petertribble.solview;

import java.util.*;
import java.io.*;
import uk.co.petertribble.jumble.*;

public class ContentsFileDetail {

  private String filename;
  //FIXME is type a string
  private String ftype;
  private String pclass;
  private String owner;
  private String group;
  private String mode;
  private long size;
  private long cksum;
  private long modtime;
  private Vector pkglist;
  //only valid for links
  private String target;
  //only valid for devices
  private String major;
  private String minor;

  /**
   * Create a set of details from a line of the contents file.
   */
  public ContentsFileDetail(String s) {
    pkglist = new Vector();
    parseNewStyle(s);
  }

  /**
   * Parse the line. We pick the name and the type, then parse the
   * rest according to the type. From contents(4)
   *
   * ftype s: path=rpath s class package
   * ftype l: path l class package
   * ftype d: path d class mode owner group package(s)
   * ftype b: path b class major minor mode owner group package
   * ftype c: path c class major minor mode owner group package
   * ftype f: path f class mode owner group size cksum modtime package
   * ftype x: path x class mode owner group package
   * ftype v: path v class mode owner group size cksum modtime package
   * ftype e: path e class mode owner group size cksum modtime package
   */
  private void parseNewStyle(String s) {
    StringTokenizer st = new StringTokenizer(s, " ");
    filename = st.nextToken();
    ftype = st.nextToken();
    pclass = st.nextToken();
    // deal with links first
    if (ftype.equals("l") || ftype.equals("s")) {
      //FIXME split the filename into name and link target
      while (st.hasMoreTokens()) {
	pkglist.addElement(st.nextToken());
      }
      return;
    }
    if (ftype.equals("b") || ftype.equals("c")) {
      major = st.nextToken();
      minor = st.nextToken();
    }
    mode = st.nextToken();
    owner = st.nextToken();
    group = st.nextToken();
    if (ftype.equals("f") || ftype.equals("v") || ftype.equals("e")) {
      size = Long.parseLong(st.nextToken());
      cksum = Long.parseLong(st.nextToken());
      modtime = Long.parseLong(st.nextToken());
    }
    //anything left is a package
    while (st.hasMoreTokens()) {
      pkglist.addElement(st.nextToken());
    }
  }

  /**
   * Parse the line (old style). From contents(4):
   *
   * ftype class path package(s)
   */
  private void parseOldStyle(String s) {
    //FIXME implement
  }

  /**
   * Return the name of the file associated with this entry.
   */
  public String getName() {
    return filename;
  }

  /**
   * Return the list of packages that own this entry
   */
  public Vector getPackages() {
    return pkglist;
  }

}
