/**
 * ContentsParser - parses the contents file
 * @author Peter Tribble
 * @version 1.0
 *
 */

package uk.co.petertribble.solview;

import java.util.*;
import java.io.*;
import uk.co.petertribble.jumble.*;

/**
 * We parse the Solaris contents file and create two hashes.
 *
 * The first hash is by file, or equivalently by line.
 * The key is the filename, the value is a ContentsFileDetail
 * which stores the metadata and the list of packages that contain
 * this file.
 *
 * The second hash is by package. The key is the package name,
 * and the value is a List of ContentsFileDetail's.
 */
public class ContentsParser {

  private String contents;
  private Hashtable fileHash;
  private Hashtable pkgHash;

  /**
   * Parse the default contents file.
   */
  public ContentsParser() {
    this("/var/sadm/install/contents");
  }

  /**
   * Parse a contents file
   */
  public ContentsParser(String contents) {
    fileHash = new Hashtable();
    pkgHash = new Hashtable();
    this.contents = contents;
    parse();
  }

  private void parse() {
    //FIXME avoid creating these large objects
    String s = JumbleFile.getStringContents(new File(contents));
    String[] ss = JumbleUtils.stringToStringArray(s, "\n");
    for (int i = 0; i < ss.length; i++) {
      ContentsFileDetail cfd = new ContentsFileDetail(ss[i]);
      fileHash.put(cfd.getName(), cfd);
    }
  }

  private void addToPkgHash(ContentsFileDetail cfd) {
    Vector v = cfd.getPackages();
    for (int j = 0; j < v.size(); j++) {
      String pkg = (String) v.get(j);
    }
  }

  public ContentsFileDetail getFileDetail(String s) {
    return (ContentsFileDetail) fileHash.get(s);
  }

}
