/**
 * SmfUtils - shows available Solaris services
 * @author Peter Tribble
 * @version 1.0
 *
 */

package uk.co.petertribble.solview;

import java.util.*;
import java.io.*;
import uk.co.petertribble.solview.helpers.*;
import uk.co.petertribble.jumble.*;

public class SmfUtils {

  private Vector services;
  private Hashtable serviceHash;

  public SmfUtils() {
    serviceHash = new Hashtable();
    services = new Vector();
    RunCommand svcs = new RunCommand("/usr/bin/svcs -aH");
    //parse the svcs output to get the service name and status
    StringTokenizer st = new StringTokenizer(svcs.getOut(), "\n");
    while (st.hasMoreTokens()) {
      String[] ds = st.nextToken().split("\\s+",3);
      //must check we got at least 3 back
      serviceHash.put(ds[2], new SmfService(ds[2],ds[0],ds[1]));
      services.add(ds[2]);
    }
 }

  public Vector getServices() {
    return services;
  }

  public String getStatus(String s) {
    return ((SmfService) serviceHash.get(s)).getStatus();
  }

  public SmfService getService(String s) {
    return (SmfService) serviceHash.get(s);
  }

  public String getHtmlInfo(String s) {
    SmfService smfserv = getService(s);
    String status = smfserv.getStatus();
    if (status.equals("offline") || status.equals("disabled")) {
      return "<pre>" + smfserv.getExplanation() + "</pre>";
    }
    if (status.equals("online")) {
      StringBuffer sb = new StringBuffer();
      sb.append("<p bgcolor=\"#cccccc\"><b>Service and Processes</b></p>");
      sb.append("<pre>").append(smfserv.getProcesses()).append("</pre>");
      sb.append("<p bgcolor=\"#cccccc\"><b>Services this service depends on</b></p>");
      sb.append("<pre>").append(smfserv.getDependencies()).append("</pre>");
      sb.append("<p bgcolor=\"#cccccc\"><b>Services that depend on this service</b></p>");
      sb.append("<pre>").append(smfserv.getDependents()).append("</pre>");
      return sb.toString();
    }
    if (status.equals("legacy_run")) {
      StringBuffer sb = new StringBuffer();
      //FIXME this is one of the ugliest hack I've ever seen
      String script = s.substring(4,12) + "." + s.substring(13);
      sb.append("<p bgcolor=\"#cccccc\"><b>");
      sb.append("This is a legacy script, file name ").append(script);
      sb.append("</b></p>");
      File fl = new File(script);
      if (fl.exists()) {
	sb.append("<pre>\n");
	sb.append("\n\nScript Contents:\n\n").append(JumbleFile.getStringContents(fl));
	sb.append("</pre>\n");
      } else {
	sb.append("\n\n(Script file not found)\n");
      }
      return sb.toString();
    }
    return status;
  }

}
